.. django-cas-server documentation master file, created by
   sphinx-quickstart on Tue Jul  5 12:11:50 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

django-cas-server documentation
===============================

Contents:

.. toctree::
   :maxdepth: 3

   README
   package/cas_server

.. toctree::
   :maxdepth: 2

   CHANGELOG

Indices and tables
==================

* :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

